==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-globalkeys/lxqt-config-globalkeyshortcuts/lxqt-config-globalkeyshortcuts_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../default_model.cpp" line="49"/>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="50"/>
        <source>DBus call</source>
        <translation>Appel DBus</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="51"/>
        <source>Client</source>
        <translation>Client</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="141"/>
        <source>Id</source>
        <translation>Id</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="144"/>
        <source>Shortcut</source>
        <translation>Raccourci</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="147"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="150"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="153"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation>Éditer l’action</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation>&amp;Raccourci :</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation>&amp;Description :</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation>&amp;Activé</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation>&amp;Commande</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation>Message D&amp;Bus</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Type :</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation>C&amp;ommande :</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation>S&amp;ervice :</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation>Chemi&amp;n :</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation>&amp;Interface :</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation>&amp;Méthode :</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translatorcomment>Not exactly the same wording but it seems more reasonable like this</translatorcomment>
        <translation>Raccourcis clavier LXQt</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="52"/>
        <source>Add ...</source>
        <translation>Ajouter…</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="62"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="72"/>
        <source>Modify ...</source>
        <translation>Modifier…</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="89"/>
        <source>Swap</source>
        <translation>Échanger</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="115"/>
        <source>Multiple actions behaviour:</source>
        <translation>Comportement en cas d’actions multiples :</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="123"/>
        <source>First</source>
        <translation>Première</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="128"/>
        <source>Last</source>
        <translation>Dernière</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="133"/>
        <source>None</source>
        <translation>Aucune</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="138"/>
        <source>All</source>
        <translation>Toutes</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="176"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>ShortcutConfigWindow</name>
    <message>
        <source>Remove</source>
        <translation type="vanished">Supprimer</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Fermer</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>None</source>
        <translation type="vanished">Aucun(e)</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Supprimer</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-globalkeys/lxqt-config-globalkeyshortcuts/lxqt-config-globalkeyshortcuts_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../../../default_model.cpp" line="49"/>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="50"/>
        <source>DBus call</source>
        <translation>Appel DBus</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="51"/>
        <source>Client</source>
        <translation>Client</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="141"/>
        <source>Id</source>
        <translation>Id</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="144"/>
        <source>Shortcut</source>
        <translation>Raccourci</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="147"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="150"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="153"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation>Éditer l’action</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation>&amp;Raccourci :</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation>&amp;Description :</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation>&amp;Activé</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation>&amp;Commande</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation>Message D&amp;Bus</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Type :</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation>C&amp;ommande :</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation>S&amp;ervice :</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation>Chemi&amp;n :</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation>&amp;Interface :</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation>&amp;Méthode :</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translatorcomment>Not exactly the same wording but it seems more reasonable like this</translatorcomment>
        <translation>Raccourcis clavier LXQt</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="52"/>
        <source>Add ...</source>
        <translation>Ajouter…</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="62"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="72"/>
        <source>Modify ...</source>
        <translation>Modifier…</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="89"/>
        <source>Swap</source>
        <translation>Échanger</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="115"/>
        <source>Multiple actions behaviour:</source>
        <translation>Comportement en cas d’actions multiples :</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="123"/>
        <source>First</source>
        <translation>Première</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="128"/>
        <source>Last</source>
        <translation>Dernière</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="133"/>
        <source>None</source>
        <translation>Aucune</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="138"/>
        <source>All</source>
        <translation>Toutes</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="176"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>ShortcutConfigWindow</name>
    <message>
        <source>Remove</source>
        <translation type="vanished">Supprimer</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Fermer</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>None</source>
        <translation type="vanished">Aucun(e)</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Supprimer</translation>
    </message>
</context>
</TS>
